@@ -451,7 +451,7 @@ class SupportCaseContact:
             self,
             response: dict
     ):
-        """Constructs a new support case comment object
+        """Constructs a new support case contact object
 
         This constructor expects a dict() object from the nebulon ON API. It
         will check the returned data against the currently implemented schema
@@ -535,8 +535,6 @@ class SupportCaseAttachment:
         """
         self.__file_name = read_value(
             "fileName", response, str, True)
-        self.__file_link = read_value(
-            "fileLink", response, str, True)
         self.__upload_time = read_value(
             "uploadTime", response, datetime, True)
         self.__file_size_bytes = read_value(
@@ -549,11 +547,6 @@ class SupportCaseAttachment:
         """The name of the uploaded file"""
         return self.__file_name
 
-    @property
-    def file_link(self) -> str:
-        """A link to the file where it is uploaded"""
-        return self.__file_link
-
     @property
     def upload_time(self) -> datetime:
         """The date and time of upload"""
@@ -573,7 +566,6 @@ class SupportCaseAttachment:
     def fields():
         return [
             "fileName",
-            "fileLink",
             "uploadTime",
             "fileSizeBytes",
             "uniqueID",
@@ -733,6 +725,11 @@ class SupportCase:
         """Unique identifier of the associated resource for the support case"""
         return self.__resource_id
 
+    @property
+    def alert_id(self) -> str:
+        """Unique identifier of an associated alert"""
+        return self.__alert_id
+
     @property
     def spu_serial(self) -> str:
         """Serial number of the associated SPU for the support case"""
