@@ -48,6 +48,9 @@ class NebPackageType(NebEnum):
     Patch = "Patch"
     """A patch package that resolves a specific issue with nebOS"""
 
+    Recovery = "Recovery"
+    """A package that is used for recovery purposes"""
+
 
 class PackageInfo:
     """A nebulon update package
@@ -383,7 +386,6 @@ class UpdateStateSpu:
         return [
             "updateID",
             "SPUSerial",
-            "spuSerial{serial}",
             "packageName",
             "downloadProgressPct",
             "waitingForSPUSerial",
@@ -615,7 +617,7 @@ class UpdatesMixin(NebMixin):
 
         # make the request
         response = self._query(
-            name="spuCustomDiagnostics",
+            name="updateState",
             params=parameters,
             fields=UpdateStateSpu.fields()
         )
